@@ -2,19 +2,19 @@ context("anova")
 
 test_that("output from infer_oneway_anova matches the expected output", {
   k <- infer_oneway_anova(mtcars, mpg, cyl)
-  expect_equal(k$between, 824.785)
-  expect_equal(k$within, 301.263)
-  expect_equal(k$total, 1126.048)
+  expect_equal(k$ss_between, 824.785)
+  expect_equal(k$ss_within, 301.263)
+  expect_equal(k$ss_total, 1126.048)
   expect_equal(k$df_btw, 2)
   expect_equal(k$df_within, 29)
   expect_equal(k$df_total, 31)
   expect_equal(k$ms_btw, 412.392)
   expect_equal(k$ms_within, 10.388)
-  expect_equal(k$f, 39.699)
-  expect_equal(k$p, 0)
+  expect_equal(k$fstat, 39.699)
+  expect_equal(k$pval, 0)
   expect_equal(k$r2, 0.7325)
-  expect_equal(k$ar2, 0.714)
-  expect_equal(k$sigma, 3.2231)
+  expect_equal(k$adjusted_r2, 0.714)
+  expect_equal(k$rmse, 3.2231)
   expect_equal(k$obs, 32)
 })
 
