@@ -52,7 +52,7 @@ test_that("output from one sample t test is as expected when alternative is less
   write      4.141    199    0.99997       2.775          -Inf      3.8828
 --------------------------------------------------------------------------------")
 
-  expect_equivalent(print(infer_os_t_test(hsb, write, mu = 50, alternative = "less")), x)
+  expect_output(print(infer_os_t_test(hsb, write, mu = 50, alternative = "less")), x)
 })
 
 test_that("output from one sample t test is as expected when alternative is greater", {
@@ -74,7 +74,7 @@ test_that("output from one sample t test is as expected when alternative is grea
   write      4.141    199    0.99997       2.775         1.6678      Inf
 --------------------------------------------------------------------------------")
 
-  expect_equivalent(print(infer_os_t_test(hsb, write, mu = 50, alternative = "greater")), x)
+  expect_output(print(infer_os_t_test(hsb, write, mu = 50, alternative = "greater")), x)
 })
 
 test_that("output from one sample t test is as expected when alternative is both", {
@@ -96,7 +96,7 @@ test_that("output from one sample t test is as expected when alternative is both
   write      4.141    199    0.99997       2.775         1.4537     4.0969
 --------------------------------------------------------------------------------")
 
-  expect_equivalent(print(infer_os_t_test(hsb, write, mu = 50, alternative = "both")), x)
+  expect_output(print(infer_os_t_test(hsb, write, mu = 50, alternative = "both")), x)
 })
 
 test_that("output from one sample t test is as expected when alternative is all", {
@@ -113,5 +113,5 @@ test_that("output from one sample t test is as expected when alternative is all"
          t = 4.141                   t = 4.141                   t = 4.141
        P < t = 1.0000             P > |t| = 0.0001             P > t = 0.0000")
 
-  expect_equivalent(print(infer_os_t_test(hsb, write, mu = 50, alternative = "all")), x)
+  expect_output(print(infer_os_t_test(hsb, write, mu = 50, alternative = "all")), x)
 })
