@@ -1,52 +1,50 @@
-context('two sample variance test')
+context("two sample variance test")
 
-test_that('output from infer_ts_var_test matches expected result', {
-
-    k <- infer_ts_var_test(mtcars$mpg, group_var = mtcars$vs)
-    expect_equal(k$f, 0.5151)
-    expect_equal(k$lower, 0.0999)
-    expect_equal(k$upper, 0.9001)
-    expect_equivalent(as.vector(k$vars), c(14.90, 28.93))
-    expect_equivalent(as.vector(k$avgs), c(16.62, 24.56))
-    expect_equivalent(as.vector(k$sds), c(3.86, 5.38))
-    expect_equivalent(as.vector(k$ses), c(0.91, 1.44))
-    expect_equal(k$avg, 20.09)
-    expect_equal(k$sd, 6.03)
-    expect_equal(k$se, 1.07)
-    expect_equal(k$len, 32)
-    expect_equivalent(as.vector(k$lens), c(18, 14))
-    expect_equal(as.vector(k$n1), 17)
-    expect_equal(as.vector(k$n2), 13)
-    expect_equivalent(k$type, 'less')
-    expect_equivalent(k$lev, c('0', '1'))
+mtcarz <- mtcars
+mtcarz$vs <- as.factor(mtcarz$vs)
 
+test_that("output from infer_ts_var_test matches expected result", {
+  k <- infer_ts_var_test(mtcarz, mpg, group_var = vs)
+  expect_equal(k$f, 0.5151)
+  expect_equal(k$lower, 0.0999)
+  expect_equal(k$upper, 0.9001)
+  expect_equivalent(as.vector(k$vars), c(14.90, 28.93))
+  expect_equivalent(as.vector(k$avgs), c(16.62, 24.56))
+  expect_equivalent(as.vector(k$sds), c(3.86, 5.38))
+  expect_equivalent(as.vector(k$ses), c(0.91, 1.44))
+  expect_equal(k$avg, 20.09)
+  expect_equal(k$sd, 6.03)
+  expect_equal(k$se, 1.07)
+  expect_equal(k$len, 32)
+  expect_equivalent(as.vector(k$lens), c(18, 14))
+  expect_equal(as.vector(k$n1), 17)
+  expect_equal(as.vector(k$n2), 13)
+  expect_equivalent(k$type, "less")
+  expect_equivalent(k$lev, c("0", "1"))
 })
 
-test_that('output from infer_ts_var_test matches expected result', {
-
-    k <- infer_ts_var_test(mtcars$mpg, mtcars$qsec)
-    expect_equal(k$f, 11.3756)
-    expect_equal(k$lower, 1)
-    expect_equal(k$upper, 0)
-    expect_equivalent(as.vector(k$vars), c(36.32, 3.19))
-    expect_equivalent(as.vector(k$avgs), c(20.09, 17.85))
-    expect_equivalent(as.vector(k$sds), c(6.03, 1.79))
-    expect_equivalent(as.vector(k$ses), c(1.07, 0.32))
-    expect_equal(k$avg, 18.97)
-    expect_equal(k$sd, 4.55)
-    expect_equal(k$se, 0.57)
-    expect_equal(k$len, 64)
-    expect_equivalent(as.vector(k$lens), c(32, 32))
-    expect_equal(unname(k$n1), 31)
-    expect_equal(unname(k$n2), 31)
-    expect_equivalent(k$type, 'less')
-    expect_equivalent(k$lev, c('mpg', 'qsec'))
-
+test_that("output from infer_ts_var_test matches expected result", {
+  k <- infer_ts_var_test(mtcarz, mpg, qsec)
+  expect_equal(k$f, 11.3756)
+  expect_equal(k$lower, 1)
+  expect_equal(k$upper, 0)
+  expect_equivalent(as.vector(k$vars), c(36.32, 3.19))
+  expect_equivalent(as.vector(k$avgs), c(20.09, 17.85))
+  expect_equivalent(as.vector(k$sds), c(6.03, 1.79))
+  expect_equivalent(as.vector(k$ses), c(1.07, 0.32))
+  expect_equal(k$avg, 18.97)
+  expect_equal(k$sd, 4.55)
+  expect_equal(k$se, 0.57)
+  expect_equal(k$len, 64)
+  expect_equivalent(as.vector(k$lens), c(32, 32))
+  expect_equal(unname(k$n1), 31)
+  expect_equal(unname(k$n2), 31)
+  expect_equivalent(k$type, "less")
+  expect_equivalent(k$lev, c("mpg", "qsec"))
 })
 
 
-test_that('output from 2 sample variance test is as expected when alternative is less', {
-
+test_that("output from 2 sample variance test is as expected when alternative is less", {
   x <- cat("               Variance Ratio Test
 --------------------------------------------------
   Group      Obs    Mean     Std. Err.    Std. Dev.
@@ -70,12 +68,10 @@ test_that('output from 2 sample variance test is as expected when alternative is
  1.1701     199       199      0.8656
 ------------------------------------")
 
-  expect_equivalent(print(infer_ts_var_test(hsb$read, hsb$write, alternative = 'less')), x)
-
+  expect_equivalent(print(infer_ts_var_test(hsb, read, write, alternative = "less")), x)
 })
 
-test_that('output from 2 sample variance test is as expected when alternative is greater', {
-
+test_that("output from 2 sample variance test is as expected when alternative is greater", {
   x <- cat("               Variance Ratio Test
 --------------------------------------------------
   Group      Obs    Mean     Std. Err.    Std. Dev.
@@ -98,12 +94,10 @@ test_that('output from 2 sample variance test is as expected when alternative is
  1.1701     199       199      0.1344
 ------------------------------------")
 
-  expect_equivalent(print(infer_ts_var_test(hsb$read, hsb$write, alternative = 'greater')), x)
-
+  expect_equivalent(print(infer_ts_var_test(hsb, read, write, alternative = "greater")), x)
 })
 
-test_that('output from 2 sample variance test is as expected when alternative is all', {
-
+test_that("output from 2 sample variance test is as expected when alternative is all", {
   x <- cat("               Variance Ratio Test
 --------------------------------------------------
   Group      Obs    Mean     Std. Err.    Std. Dev.
@@ -130,6 +124,5 @@ test_that('output from 2 sample variance test is as expected when alternative is
   Pr(F < f) = 0.8656   Pr(F > f) = 0.1344
 ----------------------------------------")
 
-  expect_equivalent(print(infer_ts_var_test(hsb$read, hsb$write, alternative = 'all')), x)
-
+  expect_equivalent(print(infer_ts_var_test(hsb, read, write, alternative = "all")), x)
 })
